@@ -4,10 +4,12 @@ library(occCite)
 
 test_that("BIEN behaves as expected", {
   skip_on_cran()
+  skip_if(!curl::has_internet(), "internet connection unsuccessful")
+
   testResult <- BIEN::BIEN_occurrence_species(
     species = "Protea cynaroides",
     cultivated = T,
-    only.new.world = F, native.status = F,
+    new.world = F, native.status = F,
     collection.info = T, natives.only = F
   )
   expect_equal(class(testResult), "data.frame")
@@ -24,6 +26,10 @@ test_that("BIEN behaves as expected", {
 
 test_that("getBIENpoints behaves as expected", {
   skip_on_cran()
+  skip_if(!curl::has_internet(), "internet connection unsuccessful")
+
+  expect_error(getBIENpoints())
+
   testResult <- getBIENpoints(taxon = "Protea cynaroides")
   expect_equal(class(testResult), "list")
   expect_equal(length(testResult), 3)
